==> nocc-1.8.1.tbz: www/nocc/lang/fr.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: fr.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** French (Français)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author IAlex
 */

$lang_locale = 'fr_FR.UTF-8';
$default_date_format = '%A %d %B %Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Vous n\'avez pas saisi de nom d\'utilisateur';
$err_passwd_empty = 'Vous n\'avez pas saisi de mot de passe';
$alt_delete = 'Effacer les messages sélectionnés';
$alt_delete_one = 'Effacer le message';
$alt_new_msg = 'Nouveaux messages';
$alt_reply = 'Répondre à l\'auteur';
$alt_reply_all = 'Répondre à tous';
$alt_forward = 'Transférer';
$alt_next = 'Suivant';
$alt_prev = 'Précédent';
$title_next_page = 'Page suivante';
$title_prev_page = 'Page précédente';
$title_next_msg = 'Message suivant';
$title_prev_msg = 'Message précédent';
$html_on = 'sur';
$html_theme_label = 'Thème :';
$html_welcome = 'Bienvenue à %1$s';
$html_login = 'Identifiant';
$html_passwd = 'Mot de passe';
$html_submit = 'Valider';
$html_help = 'Aide';
$html_server = 'Serveur';
$html_wrong = 'L\'identifiant ou le mot de passe ne sont pas valides';
$html_retry = 'Réessayer';
$html_remember = 'Conserver les paramètres';
$html_lang_label = 'Langue :';
$html_msgperpage_label = 'Messages par page :';
$html_preferences = 'Préférences';
$html_full_name_label = 'Nom complet :';
$html_email_address_label = 'Adresse de courriel :';
$html_ccself = 'Recevoir une copie';
$html_hide_addresses = 'Cacher les adresses e-mail';
$html_outlook_quoting = 'Citation à la Outlook';
$html_reply_to = 'Répondre à';
$html_use_signature = 'Utiliser la signature';
$html_signature = 'Signature';
$html_signature_label = 'Signature :';
$html_reply_leadin_label = 'Entête de réponse :';
$html_prefs_updated = 'Préférences mises à jour';
$html_manage_folders_link = 'Gestion des dossiers IMAP';
$html_manage_filters_link = 'Gestion des filtres e-mail';
$html_use_graphical_smilies = 'Utiliser les émoticones graphiques';
$html_sent_folder_label = 'Copier les éléments envoyés dans un dossier dédié :';
$html_trash_folder_label = 'Déplacer les éléments effacés dans un dossier dédié :';
$html_colored_quotes = 'Citations colorées';
$html_display_struct = 'Afficher le texte structuré';
$html_send_html_mail = 'Envoyer les courriels au format HTML';
$html_folders = 'Dossiers';
$html_folders_create_failed = 'Le dossier n\'a pas pu être créé !';
$html_folders_sub_failed = 'Impossible de s\'inscrire au dossier !';
$html_folders_unsub_failed = 'Impossible de se désinscrire du dossier !';
$html_folders_rename_failed = 'Le dossier n\'a pas pu être renommé !';
$html_folders_updated = 'Dossiers mis à jour';
$html_folder_subscribe = 'S\'inscrire à';
$html_folder_rename = 'Renommer';
$html_folder_create = 'Créer un nouveau dossier';
$html_folder_remove = 'Se désinscrire de';
$html_folder_delete = 'Supprimer';
$html_folder_to = 'vers';
$html_filter_remove = 'Supprimer';
$html_filter_body = 'Corps du message';
$html_filter_subject = 'Objet';
$html_filter_to = 'A';
$html_filter_cc = 'Cc';
$html_filter_from = 'De';
$html_filter_change_tip = 'Pour changer un filtre, réécrivez dessus.';
$html_reapply_filters = 'Réappliquer tous les filtres';
$html_filter_contains = 'contient';
$html_filter_name = 'Nom du filtre';
$html_filter_action = 'Action';
$html_filter_moveto = 'déplacer vers';
$html_select_one = '--Sélectionner--';
$html_and = 'Et';
$html_new_msg_in = 'Nouveaux messages dans';
$html_or = 'ou';
$html_move = 'Déplacer';
$html_copy = 'Copier';
$html_messages_to = 'le message sélectionné vers';
$html_gotopage = 'Aller à la page';
$html_gotofolder = 'Aller au dossier';
$html_other_folders = 'Liste des dossiers';
$html_page = 'Page';
$html_of = 'sur';
$html_view_header = 'Voir l\'entête';
$html_remove_header = 'Masquer l\'entête';
$html_inbox = 'Boîte de réception';
$html_new_msg = 'Ecrire';
$html_reply = 'Répondre';
$html_reply_short = 'Re :';
$html_reply_all = 'Répondre à tous';
$html_forward = 'Transférer';
$html_forward_short = 'Tr :';
$html_forward_info = 'Le message transféré sera envoyé en pièce jointe avec ce message.';
$html_delete = 'Supprimer';
$html_new = 'Nouveau';
$html_mark = 'Effacer';
$html_att_label = 'Pièce jointe :';
$html_atts_label = 'Pièces jointes';
$html_att_unknown = '[inconnu]';
$html_attach = 'Attacher';
$html_attach_forget = 'Vous devez attacher votre fichier avant d\'envoyer votre message !';
$html_attach_delete = 'Supprimer les fichiers sélectionnés';
$html_attach_none = 'Vous devez sélectionner un fichier à attacher !';
$html_sort_by = 'Trier par';
$html_sort = 'Trier';
$html_from = 'De';
$html_from_label = 'De :';
$html_subject = 'Sujet';
$html_subject_label = 'Objet :';
$html_date = 'Date';
$html_date_label = 'Date :';
$html_sent = 'Envoyé le :';
$html_wrote = 'a écrit';
$html_size = 'Taille';
$html_totalsize = 'Taille Totale';
$html_kb = 'ko';
$html_mb = 'Mo';
$html_gb = 'Go';
$html_bytes = 'octets';
$html_filename = 'Fichier';
$html_to = 'A';
$html_to_label = 'À :';
$html_cc = 'Copie';
$html_cc_label = 'Cc :';
$html_bcc_label = 'Copie cachée :';
$html_nosubject = 'Aucun sujet';
$html_send = 'Envoyer';
$html_cancel = 'Annuler';
$html_no_mail = 'Aucun message.';
$html_logout = 'Déconnexion';
$html_msg = 'Message';
$html_msgs = 'Messages';
$html_configuration = 'Le serveur n\'est pas correctement configuré';
$html_priority = 'Priorité';
$html_priority_label = 'Priorité :';
$html_lowest = 'Minimale';
$html_low = 'Basse';
$html_normal = 'Normale';
$html_high = 'Haute';
$html_highest = 'Maximale';
$html_receipt = 'Accusé de réception';
$html_select = 'Sélectionner';
$html_select_all = 'Inverser la sélection';
$html_loading_image = 'Chargement de l\'image';
$html_send_confirmed = 'Votre message a bien été envoyé';
$html_no_sendaction = 'Aucune action spécifiée. Essayer d\'activer JavaScript';
$html_error_occurred = 'Une erreur est survenue';
$html_prefs_file_error = 'Impossible d\'ouvrir le fichier de préférences';
$html_wrap = 'Tronquer les messages sortant à :';
$html_wrap_none = 'Pas de troncature';
$html_usenet_separator = 'Séparateur Usenet (« -- \n ») avant la signature';
$html_mark_as = 'Marquer comme';
$html_read = 'lu';
$html_unread = 'non lu';
$html_encoding_label = 'Encodage du texte :';
$html_add = 'Ajouter';
$html_contacts = 'Contacts de %1$s';
$html_modify = 'Modifier';
$html_back = 'Retour';
$html_contact_add = 'Ajouter un nouveau contact';
$html_contact_mod = 'Modifier un contact';
$html_contact_first = 'Prénom';
$html_contact_last = 'Nom';
$html_contact_nick = 'Pseudo';
$html_contact_mail = 'E-mail';
$html_contact_list = 'Liste de contacts de %1$s';
$html_contact_del = 'de la liste de contacts';
$html_contact_count = '%1$d contacts';
$html_contact_err1 = 'Le nombre maximal de contacts est « %1$d »';
$html_contact_err2 = 'Vous ne pouvez pas ajouter un nouveau contact';
$html_contact_err3 = 'Vous n\'avez pas le droit d\'accéder à la liste de contacts';
$html_contact_none = 'Aucun contact n\'a été trouvé';
$html_del_msg = 'Supprimer le(s) message(s) sélectionné(s) ?';
$html_down_mail = 'Télécharger';
$original_msg = '-- Message original --';
$to_empty = 'Le champ \'A\' ne doit pas être vide !';
$html_images_warning = 'Pour votre sécurité, les images distantes sont désactivées.';
$html_images_display = 'Afficher les images';
$html_smtp_error_no_conn = 'Impossible d\'ouvrir la connexion';
$html_smtp_error_unexpected = 'Réponse inattendue :';
$lang_could_not_connect = 'Impossible de se connecter au serveur';
$lang_invalid_msg_num = 'Mauvais numéro de message';
$html_file_upload_attack = 'Possibilité d\'attaque depuis le fichier uploadé';
$html_invalid_email_address = 'Adresse e-mail invalide';
$html_invalid_msg_per_page = 'Nombre de messages par page invalide';
$html_invalid_wrap_msg = 'Valeur de tronquature invalide';
$html_seperate_msg_win = 'Messages dans des fenêtres séparées';
$html_err_file_contacts = 'Impossible d\'ouvrir le fichier des contacts';
$html_session_file_error = 'Impossible d\'ouvrir le fichier des sessions';
$html_login_not_allowed = 'Cet identifiant n\'est pas autorisé à se connecter.';
$lang_err_send_delay = 'Vous devez attendre entre deux messages (%1$d secondes)';
$html_search = 'Rechercher';

==> nocc-1.8.3.tbz: www/nocc/lang/fr.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: fr.php 2181 2010-04-27 09:07:03Z gerundt $
 */

/** French (Français)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author IAlex
 * @author Peter17
 */

$lang_locale = 'fr_FR.UTF-8';
$default_date_format = '%A %d %B %Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Vous n\'avez pas saisi de nom d\'utilisateur';
$err_passwd_empty = 'Vous n\'avez pas saisi de mot de passe';
$alt_delete = 'Effacer les messages sélectionnés';
$alt_delete_one = 'Effacer le message';
$alt_new_msg = 'Nouveaux messages';
$alt_reply = 'Répondre à l\'auteur';
$alt_reply_all = 'Répondre à tous';
$alt_forward = 'Transférer';
$alt_next = 'Suivant';
$alt_prev = 'Précédent';
$title_next_page = 'Page suivante';
$title_prev_page = 'Page précédente';
$title_next_msg = 'Message suivant';
$title_prev_msg = 'Message précédent';
$html_theme_label = 'Thème :';
$html_welcome = 'Bienvenue à %1$s';
$html_login = 'Se connecter';
$html_user_label = 'Utilisateur :';
$html_passwd_label = 'Mot de passe :';
$html_submit = 'Valider';
$html_help = 'Aide';
$html_server_label = 'Serveur :';
$html_wrong = 'L\'identifiant ou le mot de passe ne sont pas valides';
$html_retry = 'Réessayer';
$html_remember = 'Conserver les paramètres';
$html_lang_label = 'Langue :';
$html_msgperpage_label = 'Messages par page :';
$html_preferences = 'Préférences';
$html_full_name_label = 'Nom complet :';
$html_email_address_label = 'Adresse de courriel :';
$html_ccself = 'Recevoir une copie';
$html_hide_addresses = 'Cacher les adresses e-mail';
$html_outlook_quoting = 'Citation à la Outlook';
$html_reply_to = 'Répondre à';
$html_use_signature = 'Utiliser la signature';
$html_signature = 'Signature';
$html_signature_label = 'Signature :';
$html_reply_leadin_label = 'Entête de réponse :';
$html_prefs_updated = 'Préférences mises à jour';
$html_manage_folders_link = 'Gestion des dossiers IMAP';
$html_manage_filters_link = 'Gestion des filtres e-mail';
$html_use_graphical_smilies = 'Utiliser les émoticones graphiques';
$html_sent_folder_label = 'Copier les éléments envoyés dans un dossier dédié :';
$html_trash_folder_label = 'Déplacer les éléments effacés dans un dossier dédié :';
$html_colored_quotes = 'Citations colorées';
$html_display_struct = 'Afficher le texte structuré';
$html_send_html_mail = 'Envoyer les courriels au format HTML';
$html_folders = 'Dossiers';
$html_folders_create_failed = 'Le dossier n\'a pas pu être créé !';
$html_folders_sub_failed = 'Impossible de s\'inscrire au dossier !';
$html_folders_unsub_failed = 'Impossible de se désinscrire du dossier !';
$html_folders_rename_failed = 'Le dossier n\'a pas pu être renommé !';
$html_folders_updated = 'Dossiers mis à jour';
$html_folder_subscribe = 'S\'inscrire à';
$html_folder_rename = 'Renommer';
$html_folder_create = 'Créer un nouveau dossier';
$html_folder_remove = 'Se désinscrire de';
$html_folder_delete = 'Supprimer';
$html_folder_to = 'vers';
$html_filter_remove = 'Supprimer';
$html_filter_body = 'Corps du message';
$html_filter_subject = 'Objet';
$html_filter_to = 'A';
$html_filter_cc = 'Cc';
$html_filter_from = 'De';
$html_filter_change_tip = 'Pour changer un filtre, réécrivez dessus.';
$html_reapply_filters = 'Réappliquer tous les filtres';
$html_filter_contains = 'contient';
$html_filter_name = 'Nom du filtre';
$html_filter_action = 'Action';
$html_filter_moveto = 'déplacer vers';
$html_select_one = '--Sélectionner--';
$html_and = 'Et';
$html_new_msg_in = 'Nouveaux messages dans';
$html_or = 'ou';
$html_move = 'Déplacer';
$html_copy = 'Copier';
$html_messages_to = 'le message sélectionné vers';
$html_gotopage = 'Aller à la page';
$html_gotofolder = 'Aller au dossier';
$html_other_folders = 'Liste des dossiers';
$html_page = 'Page';
$html_of = 'sur';
$html_view_header = 'Voir l\'entête';
$html_remove_header = 'Masquer l\'entête';
$html_inbox = 'Boîte de réception';
$html_new_msg = 'Ecrire';
$html_reply = 'Répondre';
$html_reply_short = 'Re :';
$html_reply_all = 'Répondre à tous';
$html_forward = 'Transférer';
$html_forward_short = 'Tr :';
$html_forward_info = 'Le message transféré sera envoyé en pièce jointe avec ce message.';
$html_delete = 'Supprimer';
$html_new = 'Nouveau';
$html_mark = 'Effacer';
$html_att_label = 'Pièce jointe :';
$html_atts_label = 'Pièces jointes :';
$html_unknown = '[inconnu]';
$html_attach = 'Attacher';
$html_attach_forget = 'Vous devez attacher votre fichier avant d\'envoyer votre message !';
$html_attach_delete = 'Supprimer les fichiers sélectionnés';
$html_attach_none = 'Vous devez sélectionner un fichier à attacher !';
$html_sort_by = 'Trier par';
$html_sort = 'Trier';
$html_from = 'De';
$html_from_label = 'De :';
$html_subject = 'Sujet';
$html_subject_label = 'Objet :';
$html_date = 'Date';
$html_date_label = 'Date :';
$html_sent_label = 'Envoyé le :';
$html_wrote = 'a écrit';
$html_size = 'Taille';
$html_totalsize = 'Taille Totale';
$html_kb = 'ko';
$html_mb = 'Mo';
$html_gb = 'Go';
$html_bytes = 'octets';
$html_filename = 'Fichier';
$html_to = 'A';
$html_to_label = 'À :';
$html_cc = 'Copie';
$html_cc_label = 'Cc :';
$html_bcc_label = 'Copie cachée :';
$html_nosubject = 'Aucun sujet';
$html_send = 'Envoyer';
$html_cancel = 'Annuler';
$html_no_mail = 'Aucun message.';
$html_logout = 'Déconnexion';
$html_msg = 'Message';
$html_msgs = 'Messages';
$html_configuration = 'Le serveur n\'est pas correctement configuré';
$html_priority = 'Priorité';
$html_priority_label = 'Priorité :';
$html_lowest = 'Minimale';
$html_low = 'Basse';
$html_normal = 'Normale';
$html_high = 'Haute';
$html_highest = 'Maximale';
$html_flagged = 'Marqué';
$html_spam = 'Spam';
$html_spam_warning = 'Ce message a été classé comme spam.';
$html_receipt = 'Accusé de réception';
$html_select = 'Sélectionner';
$html_select_all = 'Inverser la sélection';
$html_select_contacts = 'Sélectionner des contatcs';
$html_loading_image = 'Chargement de l\'image';
$html_send_confirmed = 'Votre message a bien été envoyé';
$html_no_sendaction = 'Aucune action spécifiée. Essayer d\'activer JavaScript';
$html_error_occurred = 'Une erreur est survenue';
$html_prefs_file_error = 'Impossible d\'ouvrir le fichier de préférences';
$html_wrap = 'Tronquer les messages sortant à :';
$html_wrap_none = 'Pas de troncature';
$html_usenet_separator = 'Séparateur Usenet (« -- \n ») avant la signature';
$html_mark_as = 'Marquer comme';
$html_read = 'lu';
$html_unread = 'non lu';
$html_encoding_label = 'Encodage du texte :';
$html_add = 'Ajouter';
$html_contacts = 'Contacts de %1$s';
$html_modify = 'Modifier';
$html_back = 'Retour';
$html_contact_add = 'Ajouter un nouveau contact';
$html_contact_mod = 'Modifier un contact';
$html_contact_first = 'Prénom';
$html_contact_last = 'Nom';
$html_contact_nick = 'Pseudo';
$html_contact_mail = 'E-mail';
$html_contact_list = 'Liste de contacts de %1$s';
$html_contact_del = 'de la liste de contacts';
$html_contact_count = '%1$d contacts';
$html_contact_err1 = 'Le nombre maximal de contacts est « %1$d »';
$html_contact_err2 = 'Vous ne pouvez pas ajouter un nouveau contact';
$html_contact_err3 = 'Vous n\'avez pas le droit d\'accéder à la liste de contacts';
$html_contact_none = 'Aucun contact n\'a été trouvé';
$html_del_msg = 'Supprimer le(s) message(s) sélectionné(s) ?';
$html_down_mail = 'Télécharger';
$original_msg = '-- Message original --';
$to_empty = 'Le champ \'A\' ne doit pas être vide !';
$html_images_warning = 'Pour votre sécurité, les images distantes sont désactivées.';
$html_images_display = 'Afficher les images';
$html_smtp_error_no_conn = 'Impossible d\'ouvrir la connexion';
$html_smtp_error_unexpected = 'Réponse inattendue :';
$lang_could_not_connect = 'Impossible de se connecter au serveur';
$lang_invalid_msg_num = 'Mauvais numéro de message';
$html_file_upload_attack = 'Possibilité d\'attaque depuis le fichier uploadé';
$html_invalid_email_address = 'Adresse e-mail invalide';
$html_invalid_msg_per_page = 'Nombre de messages par page invalide';
$html_invalid_wrap_msg = 'Valeur de tronquature invalide';
$html_seperate_msg_win = 'Messages dans des fenêtres séparées';
$html_err_file_contacts = 'Impossible d\'ouvrir le fichier des contacts';
$html_session_file_error = 'Impossible d\'ouvrir le fichier des sessions';
$html_login_not_allowed = 'Cet identifiant n\'est pas autorisé à se connecter.';
$lang_err_send_delay = 'Vous devez attendre entre deux messages (%1$d secondes)';
$html_search = 'Rechercher';
